﻿using System;
using System.IO;
using Foxit.PDF;
using Foxit.PDF.PageElements;

public partial class GeneratorExamples_Watermark : System.Web.UI.Page
{
    // Templates for watermark elements
    private Template template = new Template();

    protected void Page_Load(object sender, EventArgs e)
    {
        // Create a document and set it's properties
        Document document = new Document();
        document.Creator = "Watermark.aspx";
        document.Author = "Foxit Software";
        document.Title = "Watermark";
        document.Template = template;
        document.PdfVersion = PdfVersion.v1_6;

        // Adds elements to the template
        SetPageTemplate();

        // Adds Chapters to the document
        AddChapter(document, MapPath("../Text/TimeMachine_Chapter1.txt"), "1", "Chapter 1");

        // Outputs the document to the current web page
        document.DrawToWeb("Watermark.pdf");
       
    }

    private void SetPageTemplate()
    {
        // Uncomment the line below to add a layout grid to the title header page
        //headerTemplate.Elements.Add( new LayoutGrid() );

        // Create Text watermark
        TextWatermark textWatermark = new TextWatermark("Draft");
        textWatermark.TextOutlineColor = textWatermark.TextColor;
        textWatermark.TextColor = null;
        // Add Text watermark to the template
        template.Elements.Add(textWatermark);

        //uncomment the below lines to add image watermark
        //// Create Image watermark
        //ImageWatermark imageWatermark = new ImageWatermark(Server.MapPath("../Images/DPDFLogo.png"));

        //// Add Text watermark to the template
        //template.Elements.Add(imageWatermark);       
    }


    private void AddChapter(Document document, string filePath, string title, string bookmarkText)
    {
        // Retrieves the text from the sections file
        string sectionText = GetTextFromFile(filePath);

        // Adds the first page of the section
        Foxit.PDF.Page page = AddSectionHeaderPage(title, bookmarkText);

        // Creates a TextArea for the sections text
        TextArea textArea = new TextArea(sectionText, 0, 146, 324, 322, Font.TimesRoman, 11);
        textArea.Leading = 14;
        textArea.ParagraphSpacing = 20;
        page.Elements.Add(textArea);
        document.Pages.Add(page);

        // Creates a TextArea for the overflow text
        textArea = textArea.GetOverflowTextArea(0, 0, 324, 468);

        // Loops for 3 pages.
        for (int i = 0; i < 3; i++)
        {
            // Adds a new page to the document
            page = new Foxit.PDF.Page(396, 540, 36);
            page.Elements.Add(textArea);

            // Adds new page to the document
            document.Pages.Add(page);

            // Creates a TextArea for the overflow text
            textArea = textArea.GetOverflowTextArea();

        }
    }

    private string GetTextFromFile(string filePath)
    {
        // Opens a text file and returns the text from it.
        StreamReader textFile = File.OpenText(filePath);
        string sectionText = textFile.ReadToEnd();
        textFile.Close();
        return sectionText;
    }

    private Foxit.PDF.Page AddSectionHeaderPage(string title, string bookmarkText)
    {
        // Adds the first page of a section to the document
        Foxit.PDF.Page page = new Foxit.PDF.Page(396, 540, 36);

        // Uncomment the line below to add a layout grid to the section header pages
        //page.Elements.Add( new LayoutGrid() );

        page.Elements.Add(new Label("The Time Machine", 0, 36, 324, 30, Font.TimesBold, 30, TextAlign.Center));
        page.Elements.Add(new Label(title, 0, 96, 324, 22, Font.TimesBold, 22, TextAlign.Center));
        page.Elements.Add(new Line(120, 128, 204, 128));

        return page;
    }
}